@@ -40,7 +40,7 @@ use vars qw($return);
 
 use base 'Exporter';
 
-$VERSION = 1.1;
+$VERSION = 1.11;
 @EXPORT = qw(csub yield);
 
 {
@@ -135,7 +135,7 @@ the new arguments given to the subroutine on the next call.
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
+ Marc Lehmann <schmorp@schmorp.de>
  http://home.schmorp.de/
 
 =cut
