@@ -40,24 +40,15 @@
 # elif __i386__ && CORO_LINUX
 #  define STACK_ADJUST_PTR(sp,ss) ((char *)(sp) + (ss))
 #  define STACK_ADJUST_SIZE(sp,ss) (ss)
-# elif __amd64__ && CORO_LINUX
-#  define STACK_ADJUST_PTR(sp,ss) ((char *)(sp) + (ss) - 8)
-#  define STACK_ADJUST_SIZE(sp,ss) (ss)
 # else
 #  define STACK_ADJUST_PTR(sp,ss) (sp)
 #  define STACK_ADJUST_SIZE(sp,ss) (ss)
 # endif
 #endif
 
-#if CORO_SJLJ || CORO_LOSER || CORO_LINUX || CORO_IRIX
+#if CORO_SJLJ || CORO_LOOSE || CORO_LINUX || CORO_IRIX
 
-#include <stdlib.h>
-
-#if CORO_SJLJ
-# include <stdio.h>
-# include <signal.h>
-# include <unistd.h>
-#endif
+#include <signal.h>
 
 static volatile coro_func coro_init_func;
 static volatile void *coro_init_arg;
@@ -83,7 +74,7 @@ static volatile int trampoline_count;
 
 /* trampoline signal handler */
 static void
-trampoline (int sig)
+trampoline(int sig)
 {
   if (setjmp (((coro_context *)new_coro)->env))
     coro_init (); /* start it */
@@ -111,7 +102,7 @@ void coro_create(coro_context *ctx,
 
   makecontext (&(ctx->uc), (void (*)()) coro, 1, arg);
 
-#elif CORO_SJLJ || CORO_LOSER || CORO_LINUX || CORO_IRIX
+#elif CORO_SJLJ || CORO_LOOSE || CORO_LINUX || CORO_IRIX
 
 # if CORO_SJLJ
   stack_t ostk, nstk;
@@ -167,11 +158,11 @@ void coro_create(coro_context *ctx,
   if (~ostk.ss_flags & SS_DISABLE)
     sigaltstack (&ostk, 0);
 
-  sigaction (SIGUSR2, &osa, 0);
+  sigaction (SIGUSR1, &osa, 0);
 
   sigprocmask (SIG_SETMASK, &osig, 0);
 
-# elif CORO_LOSER
+# elif CORO_LOOSE
 
   setjmp (ctx->env);
   ctx->env[7] = (long)((char *)sptr + ssize);
@@ -193,7 +184,7 @@ void coro_create(coro_context *ctx,
   ctx->env[0].__jmpbuf[0].__sp = (void *)((char *)sptr + ssize);
 #elif defined(__GNU_LIBRARY__) && defined(__amd64__)
   ctx->env[0].__jmpbuf[JB_PC]  = (long)coro_init;
-  ctx->env[0].__jmpbuf[JB_RSP] = (long)STACK_ADJUST_PTR (sptr,ssize);
+  ctx->env[0].__jmpbuf[JB_RSP] = (long)((char *)sptr + ssize);
 #else
 #error "linux libc or architecture not supported"
 #endif
