@@ -28,7 +28,7 @@ use Coro::Util ();
 
 use base 'Coro::Handle';
 
-$VERSION = 1.1;
+$VERSION = 1.11;
 
 sub _proto($) {
    $_proto{$_[0]} ||= do {
@@ -202,7 +202,7 @@ sub accept {
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
+ Marc Lehmann <schmorp@schmorp.de>
  http://home.schmorp.de/
 
 =cut
